@@ -20,6 +20,9 @@
 */
 
 #include <QElapsedTimer>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+#include <QRandomGenerator>
+#endif
 #include <QDebug>
 
 #include "chaserrunner.h"
@@ -380,7 +383,11 @@ void ChaserRunner::shuffle(QVector<int> & data)
    int n = data.size();
    for (int i = n - 1; i > 0; --i)
    {
-       qSwap(data[i], data[qrand() % (i + 1)]);
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+      qSwap(data[i], data[qrand() % (i + 1)]);
+#else
+      qSwap(data[i], data[QRandomGenerator::global()->generate() % (i + 1)]);
+#endif
    }
 }
 
@@ -466,7 +473,7 @@ void ChaserRunner::clearRunningList()
         {
             // restore the original Function fade out time
             step->m_function->setOverrideFadeOutSpeed(stepFadeOut(step->m_index));
-            step->m_function->stop(functionParent());
+            step->m_function->stop(functionParent(), m_chaser->type() == Function::SequenceType);
             m_lastFunctionID = step->m_function->type() == Function::SceneType ? step->m_function->id() : Function::invalidId();
         }
         delete step;
