@@ -34,6 +34,7 @@
 #include "fixturegroup.h"
 #include "qlcclipboard.h"
 #include "mastertimer.h"
+#include "qlcpalette.h"
 #include "function.h"
 #include "fixture.h"
 
@@ -391,7 +392,7 @@ private:
      *********************************************************************/
 public:
     /** Add a new channels group. Doc takes ownership of the group. */
-    bool addChannelsGroup(ChannelsGroup *grp, quint32 id = FixtureGroup::invalidId());
+    bool addChannelsGroup(ChannelsGroup *grp, quint32 id = ChannelsGroup::invalidId());
 
     /**
      * Remove and delete a channels group.
@@ -427,9 +428,46 @@ private:
      *  in the Fixture Manager panel */
     QList <quint32> m_orderedGroups;
 
-    /** Latest assigned fixture group ID */
+    /** Latest assigned channel group ID */
     quint32 m_latestChannelsGroupId;
 
+    /*********************************************************************
+     * Palettes
+     *********************************************************************/
+public:
+    /** Add a new palette. Doc takes ownership of it */
+    bool addPalette(QLCPalette *palette, quint32 id = QLCPalette::invalidId());
+
+    /**
+     * Remove and delete a palette.
+     * The Palette pointer is invalid after this call.
+     */
+    bool deletePalette(quint32 id);
+
+    /** Get a palette by id */
+    QLCPalette *palette(quint32 id) const;
+
+    /** Get a list of Doc's palettes */
+    QList <QLCPalette*> palettes() const;
+
+private:
+    /** Create a new palette ID */
+    quint32 createPaletteId();
+
+signals:
+    /** Inform the listeners that a new palette has been added */
+    void paletteAdded(quint32 id);
+
+    /** Inform the listeners that a new palette has been removed */
+    void paletteRemoved(quint32 id);
+
+private:
+    /** Palettes */
+    QMap <quint32,QLCPalette*> m_palettes;
+
+    /** Latest assigned palette ID */
+    quint32 m_latestPaletteId;
+
     /*********************************************************************
      * Functions
      *********************************************************************/
