@@ -45,23 +45,34 @@
 #define KXMLQLCRGBMatrixPropertyName "Name"
 #define KXMLQLCRGBMatrixPropertyValue "Value"
 
+#define KXMLQLCRGBMatrixControlMode "ControlMode"
+#define KXMLQLCRGBMatrixControlModeRgb "RGB"
+#define KXMLQLCRGBMatrixControlModeAmber "Amber"
+#define KXMLQLCRGBMatrixControlModeWhite "White"
+#define KXMLQLCRGBMatrixControlModeUV "UV"
+#define KXMLQLCRGBMatrixControlModeDimmer "Dimmer"
+#define KXMLQLCRGBMatrixControlModeShutter "Shutter"
+
 /****************************************************************************
  * Initialization
  ****************************************************************************/
 
 RGBMatrix::RGBMatrix(Doc* doc)
     : Function(doc, Function::RGBMatrixType)
-    , m_dimmerControl(true)
+    , m_dimmerControl(false)
     , m_fixtureGroupID(FixtureGroup::invalidId())
     , m_group(NULL)
     , m_algorithm(NULL)
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     , m_algorithmMutex(QMutex::Recursive)
+#endif
     , m_startColor(Qt::red)
     , m_endColor(QColor())
     , m_stepHandler(new RGBMatrixStep())
     , m_roundTime(new QElapsedTimer())
     , m_stepsCount(0)
     , m_stepBeatDuration(0)
+    , m_controlMode(RGBMatrix::ControlModeRgb)
 {
     setName(tr("New RGB Matrix"));
     setDuration(500);
@@ -230,10 +241,18 @@ RGBAlgorithm* RGBMatrix::algorithm() const
     return m_algorithm;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
 QMutex& RGBMatrix::algorithmMutex()
 {
     return m_algorithmMutex;
 }
+#else
+QRecursiveMutex& RGBMatrix::algorithmMutex()
+{
+    return m_algorithmMutex;
+}
+#endif
+
 
 int RGBMatrix::stepsCount()
 {
@@ -392,6 +411,10 @@ bool RGBMatrix::loadXML(QXmlStreamReader &root)
         {
             setEndColor(QColor::fromRgb(QRgb(root.readElementText().toUInt())));
         }
+        else if (root.name() == KXMLQLCRGBMatrixControlMode)
+        {
+            setControlMode(stringToControlMode(root.readElementText()));
+        }
         else if (root.name() == KXMLQLCRGBMatrixProperty)
         {
             QString name = root.attributes().value(KXMLQLCRGBMatrixPropertyName).toString();
@@ -436,17 +459,19 @@ bool RGBMatrix::saveXML(QXmlStreamWriter *doc)
     if (m_algorithm != NULL)
         m_algorithm->saveXML(doc);
 
-    /* Dimmer Control */
-    doc->writeTextElement(KXMLQLCRGBMatrixDimmerControl, QString::number(dimmerControl()));
+    /* LEGACY - Dimmer Control */
+    if (dimmerControl())
+        doc->writeTextElement(KXMLQLCRGBMatrixDimmerControl, QString::number(dimmerControl()));
 
     /* Start Color */
     doc->writeTextElement(KXMLQLCRGBMatrixStartColor, QString::number(startColor().rgb()));
 
     /* End Color */
     if (endColor().isValid())
-    {
         doc->writeTextElement(KXMLQLCRGBMatrixEndColor, QString::number(endColor().rgb()));
-    }
+
+    /* Control Mode */
+    doc->writeTextElement(KXMLQLCRGBMatrixControlMode, RGBMatrix::controlModeToString(m_controlMode));
 
     /* Fixture Group */
     doc->writeTextElement(KXMLQLCRGBMatrixFixtureGroup, QString::number(fixtureGroup()));
@@ -698,80 +723,123 @@ void RGBMatrix::updateMapChannels(const RGBMap& map, const FixtureGroup *grp, QL
 
         QLCFixtureHead head = fxi->head(grpHead.head);
 
-        QVector <quint32> rgb = head.rgbChannels();
-        QVector <quint32> cmy = head.cmyChannels();
-
-        quint32 masterDim = fxi->masterIntensityChannel();
-        quint32 headDim = head.channelNumber(QLCChannel::Intensity, QLCChannel::MSB);
-
-        // Collect all dimmers that affect current head:
-        // They are the master dimmer (affects whole fixture)
-        // and per-head dimmer.
-        //
-        // If there are no RGB or CMY channels, the least important* dimmer channel
-        // is used to create grayscale image.
-        //
-        // The rest of the dimmer channels are set to full if dimmer control is
-        // enabled and target color is > 0 (see
-        // http://www.qlcplus.org/forum/viewtopic.php?f=29&t=11090)
-        //
-        // Note: If there is only one head, and only one dimmer channel,
-        // make it a master dimmer in fixture definition.
-        //
-        // *least important - per head dimmer if present,
-        // otherwise per fixture dimmer if present
-        QVector <quint32> dim;
-        if (masterDim != QLCChannel::invalid())
-            dim << masterDim;
-
-        if (headDim != QLCChannel::invalid())
-            dim << headDim;
-
         if (pt.y() >= map.count() || pt.x() >= map[pt.y()].count())
             continue;
 
         uint col = map[pt.y()][pt.x()];
 
-        if (rgb.size() == 3)
+        if (m_controlMode == ControlModeRgb)
         {
-            // RGB color mixing
-            FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(0));
-            updateFaderValues(fc, qRed(col), fadeTime);
+            QVector <quint32> rgb = head.rgbChannels();
+            QVector <quint32> cmy = head.cmyChannels();
 
-            fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(1));
-            updateFaderValues(fc, qGreen(col), fadeTime);
+            if (rgb.size() == 3)
+            {
+                // RGB color mixing
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(0));
+                updateFaderValues(fc, qRed(col), fadeTime);
 
-            fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(2));
-            updateFaderValues(fc, qBlue(col), fadeTime);
+                fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(1));
+                updateFaderValues(fc, qGreen(col), fadeTime);
+
+                fc = getFader(universes, fxi->universe(), grpHead.fxi, rgb.at(2));
+                updateFaderValues(fc, qBlue(col), fadeTime);
+            }
+            else if (cmy.size() == 3)
+            {
+                // CMY color mixing
+                QColor cmyCol(col);
+
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(0));
+                updateFaderValues(fc, cmyCol.cyan(), fadeTime);
+
+                fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(1));
+                updateFaderValues(fc, cmyCol.magenta(), fadeTime);
+
+                fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(2));
+                updateFaderValues(fc, cmyCol.yellow(), fadeTime);
+            }
         }
-        else if (cmy.size() == 3)
+        else if (m_controlMode == ControlModeWhite)
         {
-            // CMY color mixing
-            QColor cmyCol(col);
+            quint32 white = head.channelNumber(QLCChannel::White, QLCChannel::MSB);
 
-            FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(0));
-            updateFaderValues(fc, cmyCol.cyan(), fadeTime);
-
-            fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(1));
-            updateFaderValues(fc, cmyCol.magenta(), fadeTime);
-
-            fc = getFader(universes, fxi->universe(), grpHead.fxi, cmy.at(2));
-            updateFaderValues(fc, cmyCol.yellow(), fadeTime);
+            if (white != QLCChannel::invalid())
+            {
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, white);
+                updateFaderValues(fc, rgbToGrey(col), fadeTime);
+            }
         }
-        else if (!dim.empty())
+        else if (m_controlMode == ControlModeAmber)
         {
-            // Set dimmer to value of the color (e.g. for PARs)
-            FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, dim.last());
-            // the weights are taken from
-            // https://en.wikipedia.org/wiki/YUV#SDTV_with_BT.601
-            updateFaderValues(fc, 0.299 * qRed(col) + 0.587 * qGreen(col) + 0.114 * qBlue(col), fadeTime);
-            dim.pop_back();
+            quint32 amber = head.channelNumber(QLCChannel::Amber, QLCChannel::MSB);
+
+            if (amber != QLCChannel::invalid())
+            {
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, amber);
+                updateFaderValues(fc, rgbToGrey(col), fadeTime);
+            }
+        }
+        else if (m_controlMode == ControlModeUV)
+        {
+            quint32 uv = head.channelNumber(QLCChannel::UV, QLCChannel::MSB);
+
+            if (uv != QLCChannel::invalid())
+            {
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, uv);
+                updateFaderValues(fc, rgbToGrey(col), fadeTime);
+            }
+        }
+        else if (m_controlMode == ControlModeShutter)
+        {
+            QVector <quint32> shutters = head.shutterChannels();
+
+            if (shutters.size())
+            {
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, shutters.first());
+                updateFaderValues(fc, rgbToGrey(col), fadeTime);
+            }
         }
 
-        if (m_dimmerControl)
+        if (m_controlMode == ControlModeDimmer || m_dimmerControl)
         {
+            quint32 masterDim = fxi->masterIntensityChannel();
+            quint32 headDim = head.channelNumber(QLCChannel::Intensity, QLCChannel::MSB);
+            QVector <quint32> dimmers;
+
+            // Collect all dimmers that affect current head:
+            // They are the master dimmer (affects whole fixture)
+            // and per-head dimmer.
+            //
+            // If there are no RGB or CMY channels, the least important* dimmer channel
+            // is used to create grayscale image.
+            //
+            // The rest of the dimmer channels are set to full if dimmer control is
+            // enabled and target color is > 0 (see
+            // http://www.qlcplus.org/forum/viewtopic.php?f=29&t=11090)
+            //
+            // Note: If there is only one head, and only one dimmer channel,
+            // make it a master dimmer in fixture definition.
+            //
+            // *least important - per head dimmer if present,
+            // otherwise per fixture dimmer if present
+
+            if (masterDim != QLCChannel::invalid())
+                dimmers << masterDim;
+
+            if (headDim != QLCChannel::invalid())
+                dimmers << headDim;
+
+            if (dimmers.size())
+            {
+                // Set dimmer to value of the color (e.g. for PARs)
+                FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, dimmers.last());
+                updateFaderValues(fc, rgbToGrey(col), fadeTime);
+                dimmers.pop_back();
+            }
+
             // Set the rest of the dimmer channels to full on
-            foreach(quint32 ch, dim)
+            foreach (quint32 ch, dimmers)
             {
                 FadeChannel *fc = getFader(universes, fxi->universe(), grpHead.fxi, ch);
                 updateFaderValues(fc, col == 0 ? 0 : 255, fadeTime);
@@ -780,6 +848,13 @@ void RGBMatrix::updateMapChannels(const RGBMap& map, const FixtureGroup *grp, QL
     }
 }
 
+uchar RGBMatrix::rgbToGrey(uint col)
+{
+    // the weights are taken from
+    // https://en.wikipedia.org/wiki/YUV#SDTV_with_BT.601
+    return (0.299 * qRed(col) + 0.587 * qGreen(col) + 0.114 * qBlue(col));
+}
+
 /*********************************************************************
  * Attributes
  *********************************************************************/
@@ -819,6 +894,65 @@ void RGBMatrix::setBlendMode(Universe::BlendMode mode)
     emit changed(id());
 }
 
+/*************************************************************************
+ * Control Mode
+ *************************************************************************/
+
+RGBMatrix::ControlMode RGBMatrix::controlMode() const
+{
+    return m_controlMode;
+}
+
+void RGBMatrix::setControlMode(RGBMatrix::ControlMode mode)
+{
+    m_controlMode = mode;
+    emit changed(id());
+}
+
+RGBMatrix::ControlMode RGBMatrix::stringToControlMode(QString mode)
+{
+    if (mode == KXMLQLCRGBMatrixControlModeRgb)
+        return ControlModeRgb;
+    else if (mode == KXMLQLCRGBMatrixControlModeAmber)
+        return ControlModeAmber;
+    else if (mode == KXMLQLCRGBMatrixControlModeWhite)
+        return ControlModeWhite;
+    else if (mode == KXMLQLCRGBMatrixControlModeUV)
+        return ControlModeUV;
+    else if (mode == KXMLQLCRGBMatrixControlModeDimmer)
+        return ControlModeDimmer;
+    else if (mode == KXMLQLCRGBMatrixControlModeShutter)
+        return ControlModeShutter;
+
+    return ControlModeRgb;
+}
+
+QString RGBMatrix::controlModeToString(RGBMatrix::ControlMode mode)
+{
+    switch(mode)
+    {
+        default:
+        case ControlModeRgb:
+            return QString(KXMLQLCRGBMatrixControlModeRgb);
+        break;
+        case ControlModeAmber:
+            return QString(KXMLQLCRGBMatrixControlModeAmber);
+        break;
+        case ControlModeWhite:
+            return QString(KXMLQLCRGBMatrixControlModeWhite);
+        break;
+        case ControlModeUV:
+            return QString(KXMLQLCRGBMatrixControlModeUV);
+        break;
+        case ControlModeDimmer:
+            return QString(KXMLQLCRGBMatrixControlModeDimmer);
+        break;
+        case ControlModeShutter:
+            return QString(KXMLQLCRGBMatrixControlModeShutter);
+        break;
+    }
+}
+
 
 /*************************************************************************
  *************************************************************************
