@@ -125,6 +125,7 @@ public:
     bool dimmerControl() const;
 
 private:
+    // LEGACY: replaced by ControlModeDimmer
     bool m_dimmerControl;
 
     /*********************************************************************
@@ -163,7 +164,11 @@ public:
     RGBAlgorithm* algorithm() const;
 
     /** Get the algorithm protection mutex */
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QMutex& algorithmMutex();
+#else
+    QRecursiveMutex& algorithmMutex();
+#endif
 
     /** Get the number of steps of the current algorithm */
     int stepsCount();
@@ -173,7 +178,11 @@ public:
 
 private:
     RGBAlgorithm *m_algorithm;
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     QMutex m_algorithmMutex;
+#else
+    QRecursiveMutex m_algorithmMutex;
+#endif
 
     /************************************************************************
      * Color
@@ -242,6 +251,10 @@ private:
     /** Update FadeChannels when $map has changed since last time */
     void updateMapChannels(const RGBMap& map, const FixtureGroup* grp, QList<Universe *> universes);
 
+public:
+    /** Convert color values to fader value */
+    uchar rgbToGrey(uint col);
+
 private:
     /** Reference to a timer counting the time in ms between steps */
     QElapsedTimer *m_roundTime;
@@ -265,6 +278,34 @@ public:
 public:
     /** @reimp */
     void setBlendMode(Universe::BlendMode mode);
+
+    /*************************************************************************
+     * Control Mode
+     *************************************************************************/
+public:
+    /** Control modes for the RGB Matrix */
+    enum ControlMode
+    {
+        ControlModeRgb = 0,
+        ControlModeWhite,
+        ControlModeAmber,
+        ControlModeUV,
+        ControlModeDimmer,
+        ControlModeShutter
+    };
+
+    /** Get/Set the control mode associated to this RGBMatrix */
+    ControlMode controlMode() const;
+    void setControlMode(ControlMode mode);
+
+    /** Return a control mode from a string */
+    static ControlMode stringToControlMode(QString mode);
+
+    /** Return a string from a control mode, to be saved into a XML */
+    static QString controlModeToString(ControlMode mode);
+
+private:
+    ControlMode m_controlMode;
 };
 
 /** @} */
