@@ -20,7 +20,6 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 #include <QJSEngine>
-#include <QMutex>
 #include <QDebug>
 #include <QFile>
 
@@ -31,7 +30,11 @@
 #include "qlcfile.h"
 
 QJSEngine* RGBScript::s_engine = NULL;
-QMutex* RGBScript::s_engineMutex = NULL;
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+  QMutex* RGBScript::s_engineMutex = NULL;
+#else
+  QRecursiveMutex* RGBScript::s_engineMutex = NULL;
+#endif
 
 /****************************************************************************
  * Initialization
@@ -185,7 +188,11 @@ void RGBScript::initEngine()
 {
     if (s_engineMutex == NULL)
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         s_engineMutex = new QMutex(QMutex::Recursive);
+#else
+        s_engineMutex = new QRecursiveMutex();
+#endif
         s_engine = new QJSEngine();
     }
     Q_ASSERT(s_engineMutex != NULL);
