@@ -50,6 +50,7 @@
 #define PROP_PTR Qt::UserRole
 #define COL_NUM  0
 #define COL_NAME 1
+#define COL_ACTS_ON 2
 
 EditMode::EditMode(QWidget *parent, QLCFixtureMode *mode)
     : QDialog(parent)
@@ -114,7 +115,7 @@ void EditMode::init()
     connect(m_phyEdit, SIGNAL(requestPasteFromClipboard()), this, SIGNAL(requestPasteFromClipboard()));
 
     // Close shortcut
-    QAction* action = new QAction(this);
+    QAction *action = new QAction(this);
     action->setShortcut(QKeySequence(QKeySequence::Close));
     connect(action, SIGNAL(triggered(bool)), this, SLOT(reject()));
     addAction(action);
@@ -141,13 +142,13 @@ void EditMode::slotAddChannelClicked()
     if (ach.exec() != QDialog::Accepted)
         return;
 
-    QList <QLCChannel *> newChannelList = ach.getModeChannelsList();
+    QList<QLCChannel *> newChannelList = ach.getModeChannelsList();
 
     // clear the previous list
     m_mode->removeAllChannels();
 
     // Append the channels
-    foreach(QLCChannel *ch, newChannelList)
+    foreach (QLCChannel *ch, newChannelList)
         m_mode->insertChannel(ch, m_mode->channels().size());
 
     // Easier to refresh the whole list
@@ -156,11 +157,11 @@ void EditMode::slotAddChannelClicked()
 
 void EditMode::slotRemoveChannelClicked()
 {
-    QLCChannel* ch = currentChannel();
+    QLCChannel *ch = currentChannel();
 
     if (ch != NULL)
     {
-        QTreeWidgetItem* item;
+        QTreeWidgetItem *item;
         QString select;
 
         // Pick the item above or below to be selected next
@@ -185,7 +186,7 @@ void EditMode::slotRemoveChannelClicked()
 
 void EditMode::slotRaiseChannelClicked()
 {
-    QLCChannel* ch = currentChannel();
+    QLCChannel *ch = currentChannel();
     int index = 0;
 
     if (ch == NULL)
@@ -206,7 +207,7 @@ void EditMode::slotRaiseChannelClicked()
 
 void EditMode::slotLowerChannelClicked()
 {
-    QLCChannel* ch = currentChannel();
+    QLCChannel *ch = currentChannel();
     int index = 0;
 
     if (ch == NULL)
@@ -225,14 +226,28 @@ void EditMode::slotLowerChannelClicked()
     selectChannel(ch->name());
 }
 
+void EditMode::slotActsOnChannelChanged(QLCChannel *newActsOnChannel)
+{
+    QLCChannel *channel = currentChannel();
+
+    if (channel == NULL)
+        return;
+
+    m_mode->updateActsOnChannel(channel, newActsOnChannel);
+    refreshChannelList();
+}
+
 void EditMode::refreshChannelList()
 {
     m_channelList->clear();
 
     for (int i = 0; i < m_mode->channels().size(); i++)
     {
-        QTreeWidgetItem* item = new QTreeWidgetItem(m_channelList);
-        QLCChannel* ch = m_mode->channel(i);
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_channelList);
+        QLCChannel *ch = m_mode->channel(i);
+
+        int actsOnChannelIndex = m_mode->channels().indexOf(m_mode->actsOnChannelsList().value(ch));
+
         Q_ASSERT(ch != NULL);
 
         QString str;
@@ -240,19 +255,41 @@ void EditMode::refreshChannelList()
         item->setText(COL_NAME, ch->name());
         item->setIcon(COL_NAME, ch->getIcon());
         item->setData(COL_NAME, PROP_PTR, (qulonglong) ch);
+
+        QStringList comboList;
+
+        comboList << "-";
+
+        for (int index = 0; index < m_mode->channels().size(); index++)
+        {
+            QLCChannel *currentChannel = m_mode->channels().at(index);
+            comboList << QString::number(index) + " - " + currentChannel->name();
+        }
+
+        QComboBox *comboBox = new QComboBox(this);
+        comboBox->addItems(comboList);
+
+        if (actsOnChannelIndex >= 0)
+            comboBox->setCurrentIndex(actsOnChannelIndex + 1);
+        else
+            comboBox->setCurrentIndex(0);
+
+        m_channelList->setItemWidget(item, COL_ACTS_ON, comboBox);
+
+        connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(setActsOnChannel(int)));
     }
     m_channelList->header()->resizeSections(QHeaderView::ResizeToContents);
 }
 
 QLCChannel* EditMode::currentChannel()
 {
-    QTreeWidgetItem* item;
-    QLCChannel* ch = NULL;
+    QTreeWidgetItem *item;
+    QLCChannel *ch = NULL;
 
     // Convert the string-form ulong to a QLCChannel pointer and return it
     item = m_channelList->currentItem();
     if (item != NULL)
-        ch = (QLCChannel*) item->data(COL_NAME, PROP_PTR).toULongLong();
+        ch = (QLCChannel*)item->data(COL_NAME, PROP_PTR).toULongLong();
 
     return ch;
 }
@@ -272,6 +309,18 @@ void EditMode::selectChannel(const QString &name)
     }
 }
 
+void EditMode::setActsOnChannel(int index)
+{
+    int channelNumber = index - 1;
+
+    QLCChannel *actsOnChannel = NULL;
+
+    if (channelNumber >= 0)
+        actsOnChannel = m_mode->channels().at(channelNumber);
+
+    slotActsOnChannelChanged(actsOnChannel);
+}
+
 /****************************************************************************
  * Heads page
  ****************************************************************************/
@@ -288,7 +337,7 @@ void EditMode::slotAddHeadClicked()
 
 void EditMode::slotRemoveHeadClicked()
 {
-    QTreeWidgetItem* item = m_headList->currentItem();
+    QTreeWidgetItem *item = m_headList->currentItem();
     if (item == NULL)
         return;
 
@@ -299,7 +348,7 @@ void EditMode::slotRemoveHeadClicked()
 
 void EditMode::slotEditHeadClicked()
 {
-    QTreeWidgetItem* item = m_headList->currentItem();
+    QTreeWidgetItem *item = m_headList->currentItem();
     if (item == NULL)
         return;
 
@@ -314,7 +363,7 @@ void EditMode::slotEditHeadClicked()
 
 void EditMode::slotRaiseHeadClicked()
 {
-    QTreeWidgetItem* item = m_headList->currentItem();
+    QTreeWidgetItem *item = m_headList->currentItem();
     if (item == NULL)
         return;
 
@@ -334,7 +383,7 @@ void EditMode::slotRaiseHeadClicked()
 
 void EditMode::slotLowerHeadClicked()
 {
-    QTreeWidgetItem* item = m_headList->currentItem();
+    QTreeWidgetItem *item = m_headList->currentItem();
     if (item == NULL)
         return;
 
@@ -358,21 +407,19 @@ void EditMode::refreshHeadList()
 
     for (int i = 0; i < m_mode->heads().size(); i++)
     {
-        QTreeWidgetItem* item = new QTreeWidgetItem(m_headList);
-
+        QTreeWidgetItem *item = new QTreeWidgetItem(m_headList);
         QLCFixtureHead head = m_mode->heads().at(i);
-
         QList <quint32> channels(head.channels());
-        std::sort(channels.begin(), channels.end());
-
         QString summary;
 
+        std::sort(channels.begin(), channels.end());      
+
         QListIterator <quint32> it(channels);
         while (it.hasNext() == true)
         {
             quint32 chnum = it.next();
-            const QLCChannel* ch = m_mode->channel(chnum);
-            QTreeWidgetItem* chitem = new QTreeWidgetItem(item);
+            const QLCChannel *ch = m_mode->channel(chnum);
+            QTreeWidgetItem *chitem = new QTreeWidgetItem(item);
             if (ch != NULL)
                 chitem->setText(0, QString("%1: %2").arg(chnum + 1).arg(ch->name()));
             else
@@ -391,7 +438,7 @@ void EditMode::refreshHeadList()
 
 QLCFixtureHead EditMode::currentHead()
 {
-    QTreeWidgetItem* item = m_headList->currentItem();
+    QTreeWidgetItem *item = m_headList->currentItem();
     if (item == NULL)
         return QLCFixtureHead();
 
@@ -404,7 +451,7 @@ void EditMode::selectHead(int index)
     if (index >= m_headList->topLevelItemCount())
         return;
 
-    QTreeWidgetItem* item = m_headList->topLevelItem(index);
+    QTreeWidgetItem *item = m_headList->topLevelItem(index);
     m_headList->setCurrentItem(item);
 }
 
