@@ -512,6 +512,20 @@ void QLCFixtureEditor::slotRemoveChannel()
 
         m_channelList->setCurrentItem(next);
         setModified();
+
+        // Remove channel from modes and set nullptr for acts on channels
+        for (int i = 0; i < m_modeList->topLevelItemCount(); ++i)
+        {
+            QTreeWidgetItem *item = m_modeList->topLevelItem(i);
+
+            QLCFixtureMode *mode = (QLCFixtureMode*)item->data(MODE_COL_NAME, PROP_PTR).toULongLong();
+            mode->actsOnChannelsList().remove(channel);
+
+            QLCChannel *mainChannel = mode->actsOnChannelsList().value(channel);
+            mode->actsOnChannelsList()[mainChannel] = NULL;
+        }
+
+        refreshModeList();
     }
 }
 
