@@ -25,6 +25,7 @@
 #include <QOpenGLContext>
 #include <QPrintDialog>
 #include <QApplication>
+#include <QTranslator>
 #include <QQmlContext>
 #include <QQuickItem>
 #include <QSettings>
@@ -35,7 +36,9 @@
 
 #include "app.h"
 #include "mainview2d.h"
+#include "simpledesk.h"
 #include "showmanager.h"
+#include "fixtureeditor.h"
 #include "modelselector.h"
 #include "videoprovider.h"
 #include "importmanager.h"
@@ -71,12 +74,15 @@ App::App()
     , m_fixtureManager(nullptr)
     , m_contextManager(nullptr)
     , m_ioManager(nullptr)
+    , m_showManager(nullptr)
+    , m_simpleDesk(nullptr)
     , m_videoProvider(nullptr)
     , m_doc(nullptr)
     , m_docLoaded(false)
     , m_printItem(nullptr)
     , m_fileName(QString())
     , m_importManager(nullptr)
+    , m_fixtureEditor(nullptr)
 {
     QSettings settings;
 
@@ -95,7 +101,6 @@ App::App()
 
 App::~App()
 {
-
 }
 
 QString App::appName() const
@@ -138,7 +143,8 @@ void App::startup()
     m_fixtureManager = new FixtureManager(this, m_doc);
     m_fixtureGroupEditor = new FixtureGroupEditor(this, m_doc);
     m_functionManager = new FunctionManager(this, m_doc);
-    m_contextManager = new ContextManager(this, m_doc, m_fixtureManager, m_functionManager);
+    m_simpleDesk = new SimpleDesk(this, m_doc);
+    m_contextManager = new ContextManager(this, m_doc, m_fixtureManager, m_functionManager, m_simpleDesk);
     m_paletteManager = new PaletteManager(this, m_doc, m_contextManager);
 
     m_virtualConsole = new VirtualConsole(this, m_doc, m_contextManager);
@@ -151,7 +157,7 @@ void App::startup()
     connect(m_networkManager, &NetworkManager::requestProjectLoad, this, &App::slotLoadDocFromMemory);
 
     m_tardis = new Tardis(this, m_doc, m_networkManager, m_fixtureManager, m_functionManager,
-                          m_contextManager, m_showManager, m_virtualConsole);
+                          m_contextManager, m_simpleDesk, m_showManager, m_virtualConsole);
     rootContext()->setContextProperty("tardis", m_tardis);
 
     m_contextManager->registerContext(m_virtualConsole);
@@ -162,6 +168,7 @@ void App::startup()
     qmlRegisterUncreatableType<ContextManager>("org.qlcplus.classes", 1, 0, "ContextManager", "Can't create a ContextManager!");
     qmlRegisterUncreatableType<ShowManager>("org.qlcplus.classes", 1, 0, "ShowManager", "Can't create a ShowManager!");
     qmlRegisterUncreatableType<NetworkManager>("org.qlcplus.classes", 1, 0, "NetworkManager", "Can't create a NetworkManager!");
+    qmlRegisterUncreatableType<SimpleDesk>("org.qlcplus.classes", 1, 0, "SimpleDesk", "Can't create a NetworkManager!");
 
     // Start up in non-modified state
     m_doc->resetModified();
@@ -375,12 +382,6 @@ void App::initDoc()
     m_doc->rgbScriptsCache()->load(RGBScriptsCache::userScriptsDirectory());
 
     /* Load plugins */
-/*
-#if defined(__APPLE__) || defined(Q_OS_MAC)
-    connect(m_doc->ioPluginCache(), SIGNAL(pluginLoaded(const QString&)),
-            this, SLOT(slotSetProgressText(const QString&)));
-#endif
-*/
 #if defined Q_OS_ANDROID
     QString pluginsPath = QString("%1/../lib").arg(QDir::currentPath());
     m_doc->ioPluginCache()->load(QDir(pluginsPath));
@@ -436,10 +437,10 @@ void App::printItem(QQuickItem *item)
 void App::slotItemReadyForPrinting()
 {
     QPrinter printer;
-    QPrintDialog *dlg = new QPrintDialog(&printer, 0);
+    QPrintDialog *dlg = new QPrintDialog(&printer);
     if(dlg->exec() == QDialog::Accepted)
     {
-        QRectF pageRect = printer.pageRect();
+        QRectF pageRect = printer.pageLayout().paintRect();
         QSize imgSize = m_printerImage->image().size();
         int totalHeight = imgSize.height();
         int yOffset = 0;
@@ -656,34 +657,6 @@ bool App::saveWorkspace(const QString &fileName)
     return false;
 }
 
-bool App::loadImportWorkspace(const QString &fileName)
-{
-    if (m_importManager != nullptr)
-        delete m_importManager;
-
-    m_importManager = new ImportManager(this, m_doc);
-    return m_importManager->loadWorkspace(fileName);
-}
-
-void App::cancelImport()
-{
-    if (m_importManager != nullptr)
-        delete m_importManager;
-
-    m_importManager = nullptr;
-}
-
-void App::importFromWorkspace()
-{
-    if (m_importManager == nullptr)
-        return;
-
-    m_importManager->apply();
-
-    delete m_importManager;
-    m_importManager = nullptr;
-}
-
 QFileDevice::FileError App::loadXML(const QString &fileName)
 {
     QFile::FileError retval = QFile::NoError;
@@ -868,5 +841,91 @@ QFile::FileError App::saveXML(const QString& fileName)
     return QFile::NoError;
 }
 
+/*********************************************************************
+ * Import project
+ *********************************************************************/
 
+bool App::loadImportWorkspace(const QString &fileName)
+{
+    if (m_importManager != nullptr)
+        delete m_importManager;
+
+    m_importManager = new ImportManager(this, m_doc);
+    return m_importManager->loadWorkspace(fileName);
+}
+
+void App::cancelImport()
+{
+    if (m_importManager != nullptr)
+        delete m_importManager;
+
+    m_importManager = nullptr;
+}
+
+void App::importFromWorkspace()
+{
+    if (m_importManager == nullptr)
+        return;
+
+    m_importManager->apply();
+
+    delete m_importManager;
+    m_importManager = nullptr;
+}
+
+/*********************************************************************
+ * Fixture editor
+ *********************************************************************/
+
+void App::createFixture()
+{
+    if (m_fixtureEditor == nullptr)
+    {
+        m_fixtureEditor = new FixtureEditor(this, m_doc);
+        QMetaObject::invokeMethod(rootObject(), "switchToContext",
+                                  Q_ARG(QVariant, "FXEDITOR"),
+                                  Q_ARG(QVariant, "qrc:/FixtureEditor.qml"));
+    }
+
+    m_fixtureEditor->createDefinition();
+}
+
+void App::loadFixture(QString fileName)
+{
+    if (m_fixtureEditor == nullptr)
+    {
+        m_fixtureEditor = new FixtureEditor(this, m_doc);
+        QMetaObject::invokeMethod(rootObject(), "switchToContext",
+                                  Q_ARG(QVariant, "FXEDITOR"),
+                                  Q_ARG(QVariant, "qrc:/FixtureEditor.qml"));
+    }
+    m_fixtureEditor->loadDefinition(fileName);
+}
+
+void App::editFixture(QString manufacturer, QString model)
+{
+    if (m_fixtureEditor == nullptr)
+    {
+        m_fixtureEditor = new FixtureEditor(this, m_doc);
+        QMetaObject::invokeMethod(rootObject(), "switchToContext",
+                                  Q_ARG(QVariant, "FXEDITOR"),
+                                  Q_ARG(QVariant, "qrc:/FixtureEditor.qml"));
+    }
+    m_fixtureEditor->editDefinition(manufacturer, model);
+}
+
+void App::closeFixtureEditor()
+{
+    if (m_fixtureEditor)
+    {
+        delete m_fixtureEditor;
+        m_fixtureEditor = nullptr;
+    }
+
+    // reload the QLC+ main view
+    //setSource(QUrl("qrc:/MainView.qml"));
+    QMetaObject::invokeMethod(rootObject(), "switchToContext",
+                              Q_ARG(QVariant, "FIXANDFUNC"),
+                              Q_ARG(QVariant, "qrc:/FixturesAndFunctions.qml"));
+}
 
