@@ -1074,14 +1074,14 @@ quint32 FunctionManager::getChannelTypeMask(quint32 fxID, quint32 channel)
 void FunctionManager::dumpOnNewScene(QList<SceneValue> dumpValues, QList<quint32> selectedFixtures,
                                      quint32 channelMask, QString name)
 {
-    if (selectedFixtures.isEmpty() || dumpValues.isEmpty() || channelMask == 0)
+    if (dumpValues.isEmpty() || channelMask == 0)
         return;
 
     Scene *newScene = new Scene(m_doc);
 
     for (SceneValue sv : dumpValues)
     {
-        if (selectedFixtures.contains(sv.fxi) == false)
+        if (selectedFixtures.count() && selectedFixtures.contains(sv.fxi) == false)
             continue;
 
         quint32 chTypeBit = getChannelTypeMask(sv.fxi, sv.channel);
@@ -1108,7 +1108,7 @@ void FunctionManager::dumpOnNewScene(QList<SceneValue> dumpValues, QList<quint32
 void FunctionManager::dumpOnScene(QList<SceneValue> dumpValues, QList<quint32> selectedFixtures,
                                   quint32 channelMask, quint32 sceneID)
 {
-    if (selectedFixtures.isEmpty() || dumpValues.isEmpty() || channelMask == 0)
+    if (dumpValues.isEmpty() || channelMask == 0)
         return;
 
     Scene *scene = qobject_cast<Scene *>(m_doc->function(sceneID));
@@ -1118,7 +1118,7 @@ void FunctionManager::dumpOnScene(QList<SceneValue> dumpValues, QList<quint32> s
 
     for (SceneValue sv : dumpValues)
     {
-        if (selectedFixtures.contains(sv.fxi) == false)
+        if (selectedFixtures.count() && selectedFixtures.contains(sv.fxi) == false)
             continue;
 
         quint32 chTypeBit = getChannelTypeMask(sv.fxi, sv.channel);
