@@ -29,6 +29,7 @@
 #include "functionmanager.h"
 #include "contextmanager.h"
 #include "functioneditor.h"
+#include "simpledesk.h"
 #include "collection.h"
 #include "rgbmatrix.h"
 #include "vccuelist.h"
@@ -55,7 +56,7 @@
 Tardis* Tardis::s_instance = nullptr;
 
 Tardis::Tardis(QQuickView *view, Doc *doc, NetworkManager *netMgr,
-               FixtureManager *fxMgr, FunctionManager *funcMgr, ContextManager *ctxMgr,
+               FixtureManager *fxMgr, FunctionManager *funcMgr, ContextManager *ctxMgr, SimpleDesk *sDesk,
                ShowManager *showMgr, VirtualConsole *vc, QObject *parent)
     : QThread(parent)
     , m_running(false)
@@ -65,6 +66,7 @@ Tardis::Tardis(QQuickView *view, Doc *doc, NetworkManager *netMgr,
     , m_fixtureManager(fxMgr)
     , m_functionManager(funcMgr)
     , m_contextManager(ctxMgr)
+    , m_simpleDesk(sDesk)
     , m_showManager(showMgr)
     , m_virtualConsole(vc)
     , m_historyIndex(-1)
@@ -955,6 +957,30 @@ int Tardis::processAction(TardisAction &action, bool undo)
         }
         break;
 
+        /* ************************* Simple Desk actions ************************** */
+
+        case SimpleDeskSetChannel:
+        {
+            SceneValue scv = value->value<SceneValue>();
+            if (scv.channel == QLCChannel::invalid())
+            {
+                SceneValue newVal = action.m_newValue.value<SceneValue>();
+                m_simpleDesk->resetChannel(newVal.channel);
+            }
+            else
+                m_simpleDesk->setValue(scv.fxi, scv.channel, scv.value);
+        }
+        break;
+        case SimpleDeskResetChannel:
+        {
+            SceneValue scv = value->value<SceneValue>();
+            if (undo)
+                m_simpleDesk->setValue(scv.fxi, scv.channel, scv.value);
+            else
+                m_simpleDesk->resetChannel(scv.channel);
+        }
+        break;
+
         /* ******************* Virtual console editing actions ******************** */
 
         case VCWidgetCreate:
